window.Gleam.initSearch([{"doc":"adglent","title":"adglent","content":"# adglent\n\n[![Package Version](https://img.shields.io/hexpm/v/adglent)](https://hex.pm/packages/adglent)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/adglent/)\n\n## About\n\n`adglent` is a Gleam library which can be used to setup testing code and a template for implementing solution to [Advent of code](https://adventofcode.com/) problems.\n\n&gt; NOTE: `adglent` **only** supports `erlang` target (default) for Gleam.\n\n## Installation\n\nStart a new gleam project for your AOC soluctions with `gleam new`. In the project folder run:\n\n```sh\ngleam add --dev adglent\n```\n\n## Usage\n\n### Initializing\n\nFirst log in to [Advent of code](https://adventofcode.com/) and copy your personal `session-cookie`. The value can be found using developer tools in the browser (in Chrome: &quot;Application-&gt;Cookies-&gt;https://adventofcode.com-&gt;session&quot; and copy the Cookie-value)\n\n```sh\ngleam run -m adglent/init\n```\n\nInput the AOC year, you personal AOC session cookie and select if `showtime` should be used for tests (otherwise it will assume the project uses `gleeunit` as is default for `gleam new &lt;project&gt;`)\n\n&gt; NOTE: `showtime` is an alternate gleam test-runner. It is still quite new and havn&#39;t been tested in as many project as `gleeunit`. It has a different way of formatting the test-results and also supports the possibility to run specific test-modules (which can be useful in AOC). `showtime` is a standalone project but have been embedded into `adglent`.\n\n### Add day\n\nTo start working on the solution for a specific day run:\n\n```sh\ngleam run -m adglent/day &lt;NUM&gt;\n```\n\nWhere `&lt;NUM&gt;` is the day number of the day you want to solve a problem for.\n\n&gt; Example (start solving 1st of December):\n&gt;\n&gt; ```sh\n&gt; gleam run -m adglent/day 1\n&gt; ```\n\nAdding a day will add tests in `test/day&lt;NUM&gt;/day&lt;NUM&gt;_test.gleam`and a `src/day&lt;NUM&gt;/solve.gleam` file where the solution can be implemented.\n\nFurthermore it will also download the input for the problem to `src/day&lt;NUM&gt;/input.txt`\n\nBefore running the tests you need to provide one or more example. These can be found in the problem description for that day at the AOC website.\n\nAdd an example to a part of the problem by adding examples to the `part1_examples` or `part2_examples` lists.\n\n&gt; Example (input &quot;Hello Joe!&quot; should give answer 613411):\n&gt;\n&gt; ```gleam\n&gt; const part1_examples: List(Example(Problem1AnswerType)) = [\n&gt;   Example(&quot;Hello Joe!&quot;, &quot;613411&quot;),\n&gt; ]\n&gt; ```\n\nThe type of the answer for a part can be adjusted if needed by changing the type aliases `Problem1AnswerType` / `Problem2AnswerType`. Note that this will change the type that the `part1` / `part2` functions in `solve.gleam` expect to return.\n\n### Testing\n\nTo test all days in the project use:\n\n```sh\ngleam test\n```\n\nIf you are using `showtime` you can test a single day by running:\n\n```sh\ngleam test -- --modules=day&lt;NUM&gt;/day&lt;NUM&gt;_test\n```\n\n&gt; Example (test solution for 1st of December):\n&gt;\n&gt; ```sh\n&gt; gleam test -- modules=day1/day1_test\n&gt; ```\n\n### Get the answer\n\nTo get the (hopefully correct) answer after the tests are ok run:\n\n```sh\ngleam run -m day&lt;NUM&gt;/solve &lt;PART&gt;\n```\n\nwhere `&lt;NUM&gt;` is the day to solve and `&lt;PART&gt;` is the part of the problem (1 or 2) to solve.\n\nThis will run the solver and print the answer to stdout.\n\n### Module documentation\n\nModule documentation can be found at &lt;https://hexdocs.pm/adglent&gt;.\n","url":"index.html"},{"doc":"priv/templates/test_main","title":"template","content":"pub const template: String = &quot;\nimport showtime\n\npub fn main() {\n  showtime.main()\n}\n&quot;\n\nSynonyms:\npriv/templates/test_main.template\npriv/templates/test_main template","url":"priv/templates/test_main.html#template"},{"doc":"priv/templates/test_main","title":"priv/templates/test_main","content":"","url":"priv/templates/test_main.html"},{"doc":"priv/templates/testfile_gleeunit","title":"template","content":"pub const template: String = &quot;\nimport gleam/list\nimport gleeunit/should\nimport adglent.{type Example, Example}\nimport day{{ day }}/solve\n\ntype Problem1AnswerType =\n  String\n\ntype Problem2AnswerType =\n  String\n\n/// Add examples for part 1 here:\n/// ```gleam\n///const part1_examples: List(Example(Problem1AnswerType)) = [Example(\\&quot;some input\\&quot;, \\&quot;\\&quot;)]\n/// ```\nconst part1_examples: List(Example(Problem1AnswerType)) = []\n\n/// Add examples for part 2 here:\n/// ```gleam\n///const part2_examples: List(Example(Problem2AnswerType)) = [Example(\\&quot;some input\\&quot;, \\&quot;\\&quot;)]\n/// ```\nconst part2_examples: List(Example(Problem2AnswerType)) = []\n\npub fn part1_test() {\n  part1_examples\n  |&gt; should.not_equal([])\n  use example &lt;- list.map(part1_examples)\n  solve.part1(example.input)\n  |&gt; should.equal(example.answer)\n}\n\npub fn part2_test() {\n  part2_examples\n  |&gt; should.not_equal([])\n  use example &lt;- list.map(part2_examples)\n  solve.part2(example.input)\n  |&gt; should.equal(example.answer)\n}\n\n&quot;\n\nSynonyms:\npriv/templates/testfile_gleeunit.template\npriv/templates/testfile_gleeunit template","url":"priv/templates/testfile_gleeunit.html#template"},{"doc":"priv/templates/testfile_gleeunit","title":"priv/templates/testfile_gleeunit","content":"","url":"priv/templates/testfile_gleeunit.html"},{"doc":"priv/prompt","title":"GetLineError","content":"pub type GetLineError {\n  Eof\n  NoData\n}\n\nEof\n\n\nNoData\n\n\nSynonyms:\npriv/prompt.GetLineError\npriv/prompt GetLineError","url":"priv/prompt.html#GetLineError"},{"doc":"priv/prompt","title":"confirm","content":"pub fn confirm(message: String, auto_accept: Bool) -&gt; Bool\n\nSynonyms:\npriv/prompt.confirm\npriv/prompt confirm","url":"priv/prompt.html#confirm"},{"doc":"priv/prompt","title":"get_line","content":"pub fn get_line(\n  prompt prompt: String,\n) -&gt; Result(String, GetLineError)\n\nSynonyms:\npriv/prompt.get_line\npriv/prompt get_line","url":"priv/prompt.html#get_line"},{"doc":"priv/prompt","title":"value","content":"pub fn value(\n  message: String,\n  default: String,\n  auto_accept: Bool,\n) -&gt; String\n\nSynonyms:\npriv/prompt.value\npriv/prompt value","url":"priv/prompt.html#value"},{"doc":"priv/prompt","title":"priv/prompt","content":"","url":"priv/prompt.html"},{"doc":"adglent","title":"Example","content":"pub type Example(a) {\n  Example(input: String, answer: a)\n}\n\nExample(input: String, answer: a)\n\n\nSynonyms:\nadglent.Example\nadglent Example","url":"adglent.html#Example"},{"doc":"adglent","title":"Problem","content":"pub type Problem {\n  First\n  Second\n}\n\nFirst\n\n\nSecond\n\n\nSynonyms:\nadglent.Problem\nadglent Problem","url":"adglent.html#Problem"},{"doc":"adglent","title":"get_input","content":"pub fn get_input(day: String) -&gt; Result(String, FileError)\n\nSynonyms:\nadglent.get_input\nadglent get_input","url":"adglent.html#get_input"},{"doc":"adglent","title":"get_part","content":"pub fn get_part() -&gt; Result(Problem, Nil)\n\nSynonyms:\nadglent.get_part\nadglent get_part","url":"adglent.html#get_part"},{"doc":"adglent","title":"get_test_folder","content":"pub fn get_test_folder(day: String) -&gt; String\n\nSynonyms:\nadglent.get_test_folder\nadglent get_test_folder","url":"adglent.html#get_test_folder"},{"doc":"adglent","title":"inspect","content":"pub fn inspect(value: a) -&gt; String\n\nSynonyms:\nadglent.inspect\nadglent inspect","url":"adglent.html#inspect"},{"doc":"adglent","title":"start_arguments","content":"pub fn start_arguments() -&gt; List(String)\n\nSynonyms:\nadglent.start_arguments\nadglent start_arguments","url":"adglent.html#start_arguments"},{"doc":"adglent","title":"adglent","content":"","url":"adglent.html"},{"doc":"priv/template","title":"render","content":"pub fn render(\n  template: String,\n  substitutions: List(#(String, String)),\n) -&gt; String\n\nSynonyms:\npriv/template.render\npriv/template render","url":"priv/template.html#render"},{"doc":"priv/template","title":"priv/template","content":"","url":"priv/template.html"},{"doc":"priv/templates/testfile_showtime","title":"template","content":"pub const template: String = &quot;\nimport gleam/list\nimport showtime/tests/should\nimport adglent.{type Example, Example}\nimport day{{ day }}/solve\n\ntype Problem1AnswerType =\n  String\n\ntype Problem2AnswerType =\n  String\n\n/// Add examples for part 1 here:\n/// ```gleam\n///const part1_examples: List(Example(Problem1AnswerType)) = [Example(\\&quot;some input\\&quot;, \\&quot;\\&quot;)]\n/// ```\nconst part1_examples: List(Example(Problem1AnswerType)) = []\n\n/// Add examples for part 2 here:\n/// ```gleam\n///const part2_examples: List(Example(Problem2AnswerType)) = [Example(\\&quot;some input\\&quot;, \\&quot;\\&quot;)]\n/// ```\nconst part2_examples: List(Example(Problem2AnswerType)) = []\n\npub fn part1_test() {\n  part1_examples\n  |&gt; should.not_equal([])\n  use example &lt;- list.map(part1_examples)\n  solve.part1(example.input)\n  |&gt; should.equal(example.answer)\n}\n\npub fn part2_test() {\n  part2_examples\n  |&gt; should.not_equal([])\n  use example &lt;- list.map(part2_examples)\n  solve.part2(example.input)\n  |&gt; should.equal(example.answer)\n}\n\n&quot;\n\nSynonyms:\npriv/templates/testfile_showtime.template\npriv/templates/testfile_showtime template","url":"priv/templates/testfile_showtime.html#template"},{"doc":"priv/templates/testfile_showtime","title":"priv/templates/testfile_showtime","content":"","url":"priv/templates/testfile_showtime.html"},{"doc":"priv/templates/solution","title":"template","content":"pub const template: String = &quot;\nimport adglent.{First, Second}\nimport gleam/io\n\npub fn part1(input: String) {\n  todo as \\&quot;Implement solution to part 1\\&quot;\n}\n\npub fn part2(input: String) {\n  todo as \\&quot;Implement solution to part 2\\&quot;\n}\n\npub fn main() {\n  let assert Ok(part) = adglent.get_part()\n  let assert Ok(input) = adglent.get_input(\\&quot;{{ day }}\\&quot;)\n  case part {\n    First -&gt;\n      part1(input)\n      |&gt; adglent.inspect\n      |&gt; io.println\n    Second -&gt;\n      part2(input)\n      |&gt; adglent.inspect\n      |&gt; io.println\n  }\n}\n&quot;\n\nSynonyms:\npriv/templates/solution.template\npriv/templates/solution template","url":"priv/templates/solution.html#template"},{"doc":"priv/templates/solution","title":"priv/templates/solution","content":"","url":"priv/templates/solution.html"},{"doc":"priv/toml","title":"Toml","content":"pub type Toml\n\n\nSynonyms:\npriv/toml.Toml\npriv/toml Toml","url":"priv/toml.html#Toml"},{"doc":"priv/toml","title":"do_toml_get","content":"pub fn do_toml_get(\n  toml: Toml,\n  keys: List(String),\n) -&gt; Result(Dynamic, Nil)\n\nSynonyms:\npriv/toml.do_toml_get\npriv/toml do_toml_get","url":"priv/toml.html#do_toml_get"},{"doc":"priv/toml","title":"get_bool","content":"pub fn get_bool(\n  toml_content: String,\n  key_path: List(String),\n) -&gt; Result(Bool, Nil)\n\nSynonyms:\npriv/toml.get_bool\npriv/toml get_bool","url":"priv/toml.html#get_bool"},{"doc":"priv/toml","title":"get_string","content":"pub fn get_string(\n  toml_content: String,\n  key_path: List(String),\n) -&gt; Result(String, Nil)\n\nSynonyms:\npriv/toml.get_string\npriv/toml get_string","url":"priv/toml.html#get_string"},{"doc":"priv/toml","title":"parse","content":"pub fn parse(content: String) -&gt; Result(Toml, Nil)\n\nSynonyms:\npriv/toml.parse\npriv/toml parse","url":"priv/toml.html#parse"},{"doc":"priv/toml","title":"priv/toml","content":"","url":"priv/toml.html"},{"doc":"priv/aoc_client","title":"get_input","content":"pub fn get_input(\n  year: String,\n  day: String,\n  session: String,\n) -&gt; Result(String, Error)\n\nSynonyms:\npriv/aoc_client.get_input\npriv/aoc_client get_input","url":"priv/aoc_client.html#get_input"},{"doc":"priv/aoc_client","title":"priv/aoc_client","content":"","url":"priv/aoc_client.html"},{"doc":"priv/errors","title":"assert_ok","content":"pub fn assert_ok(result: Result(a, String)) -&gt; a\n\nSynonyms:\npriv/errors.assert_ok\npriv/errors assert_ok","url":"priv/errors.html#assert_ok"},{"doc":"priv/errors","title":"map_error","content":"pub fn map_error(\n  result: Result(a, b),\n  error_message: String,\n) -&gt; Result(a, String)\n\nSynonyms:\npriv/errors.map_error\npriv/errors map_error","url":"priv/errors.html#map_error"},{"doc":"priv/errors","title":"map_messages","content":"pub fn map_messages(\n  result: Result(a, b),\n  success_message: String,\n  error_message: String,\n) -&gt; Result(String, String)\n\nSynonyms:\npriv/errors.map_messages\npriv/errors map_messages","url":"priv/errors.html#map_messages"},{"doc":"priv/errors","title":"print_error","content":"pub fn print_error(\n  result: Result(a, String),\n) -&gt; Result(a, String)\n\nSynonyms:\npriv/errors.print_error\npriv/errors print_error","url":"priv/errors.html#print_error"},{"doc":"priv/errors","title":"print_result","content":"pub fn print_result(\n  result: Result(String, String),\n) -&gt; Result(String, String)\n\nSynonyms:\npriv/errors.print_result\npriv/errors print_result","url":"priv/errors.html#print_result"},{"doc":"priv/errors","title":"priv/errors","content":"","url":"priv/errors.html"},{"doc":"adglent/day","title":"main","content":"pub fn main() -&gt; String\n\nSynonyms:\nadglent/day.main\nadglent/day main","url":"adglent/day.html#main"},{"doc":"adglent/day","title":"adglent/day","content":"","url":"adglent/day.html"},{"doc":"showtime/tests/meta","title":"Meta","content":"pub type Meta {\n  Meta(description: String, tags: List(String))\n}\n\nMeta(description: String, tags: List(String))\n\n\nSynonyms:\nshowtime/tests/meta.Meta\nshowtime/tests/meta Meta","url":"showtime/tests/meta.html#Meta"},{"doc":"showtime/tests/meta","title":"showtime/tests/meta","content":"","url":"showtime/tests/meta.html"},{"doc":"showtime/tests/should","title":"Assertion","content":"pub type Assertion(t, e) {\n  Eq(a: t, b: t, meta: Option(Meta))\n  NotEq(a: t, b: t, meta: Option(Meta))\n  IsOk(a: Result(t, e), meta: Option(Meta))\n  IsError(a: Result(t, e), meta: Option(Meta))\n  Fail(meta: Option(Meta))\n}\n\nEq(a: t, b: t, meta: Option(Meta))\n\n\nNotEq(a: t, b: t, meta: Option(Meta))\n\n\nIsOk(a: Result(t, e), meta: Option(Meta))\n\n\nIsError(a: Result(t, e), meta: Option(Meta))\n\n\nFail(meta: Option(Meta))\n\n\nSynonyms:\nshowtime/tests/should.Assertion\nshowtime/tests/should Assertion","url":"showtime/tests/should.html#Assertion"},{"doc":"showtime/tests/should","title":"be_error","content":"pub fn be_error(a: Result(a, b)) -&gt; b\n\nSynonyms:\nshowtime/tests/should.be_error\nshowtime/tests/should be_error","url":"showtime/tests/should.html#be_error"},{"doc":"showtime/tests/should","title":"be_error_meta","content":"pub fn be_error_meta(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_error_meta\nshowtime/tests/should be_error_meta","url":"showtime/tests/should.html#be_error_meta"},{"doc":"showtime/tests/should","title":"be_false","content":"pub fn be_false(a: Bool) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_false\nshowtime/tests/should be_false","url":"showtime/tests/should.html#be_false"},{"doc":"showtime/tests/should","title":"be_false_meta","content":"pub fn be_false_meta(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_false_meta\nshowtime/tests/should be_false_meta","url":"showtime/tests/should.html#be_false_meta"},{"doc":"showtime/tests/should","title":"be_ok","content":"pub fn be_ok(a: Result(a, b)) -&gt; a\n\nSynonyms:\nshowtime/tests/should.be_ok\nshowtime/tests/should be_ok","url":"showtime/tests/should.html#be_ok"},{"doc":"showtime/tests/should","title":"be_ok_meta","content":"pub fn be_ok_meta(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_ok_meta\nshowtime/tests/should be_ok_meta","url":"showtime/tests/should.html#be_ok_meta"},{"doc":"showtime/tests/should","title":"be_true","content":"pub fn be_true(a: Bool) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_true\nshowtime/tests/should be_true","url":"showtime/tests/should.html#be_true"},{"doc":"showtime/tests/should","title":"be_true_meta","content":"pub fn be_true_meta(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.be_true_meta\nshowtime/tests/should be_true_meta","url":"showtime/tests/should.html#be_true_meta"},{"doc":"showtime/tests/should","title":"equal","content":"pub fn equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.equal\nshowtime/tests/should equal","url":"showtime/tests/should.html#equal"},{"doc":"showtime/tests/should","title":"equal_meta","content":"pub fn equal_meta(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.equal_meta\nshowtime/tests/should equal_meta","url":"showtime/tests/should.html#equal_meta"},{"doc":"showtime/tests/should","title":"evaluate","content":"pub fn evaluate(assertion: Assertion(a, b)) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.evaluate\nshowtime/tests/should evaluate","url":"showtime/tests/should.html#evaluate"},{"doc":"showtime/tests/should","title":"fail","content":"pub fn fail() -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.fail\nshowtime/tests/should fail","url":"showtime/tests/should.html#fail"},{"doc":"showtime/tests/should","title":"fail_meta","content":"pub fn fail_meta(meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.fail_meta\nshowtime/tests/should fail_meta","url":"showtime/tests/should.html#fail_meta"},{"doc":"showtime/tests/should","title":"not_equal","content":"pub fn not_equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.not_equal\nshowtime/tests/should not_equal","url":"showtime/tests/should.html#not_equal"},{"doc":"showtime/tests/should","title":"not_equal_meta","content":"pub fn not_equal_meta(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/should.not_equal_meta\nshowtime/tests/should not_equal_meta","url":"showtime/tests/should.html#not_equal_meta"},{"doc":"showtime/tests/should","title":"showtime/tests/should","content":"","url":"showtime/tests/should.html"},{"doc":"showtime","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nshowtime.main\nshowtime main","url":"showtime.html#main"},{"doc":"showtime","title":"showtime","content":"","url":"showtime.html"},{"doc":"adglent/init","title":"main","content":"pub fn main() -&gt; Result(String, String)\n\nSynonyms:\nadglent/init.main\nadglent/init main","url":"adglent/init.html#main"},{"doc":"adglent/init","title":"adglent/init","content":"","url":"adglent/init.html"},{"doc":"showtime/tests/test","title":"MetaShould","content":"pub type MetaShould(t) {\n  MetaShould(equal: fn(t, t) -&gt; Nil, not_equal: fn(t, t) -&gt; Nil)\n}\n\nMetaShould(equal: fn(t, t) -&gt; Nil, not_equal: fn(t, t) -&gt; Nil)\n\n\nSynonyms:\nshowtime/tests/test.MetaShould\nshowtime/tests/test MetaShould","url":"showtime/tests/test.html#MetaShould"},{"doc":"showtime/tests/test","title":"Test","content":"pub type Test {\n  Test(meta: Meta, test_function: fn() -&gt; Nil)\n}\n\nTest(meta: Meta, test_function: fn() -&gt; Nil)\n\n\nSynonyms:\nshowtime/tests/test.Test\nshowtime/tests/test Test","url":"showtime/tests/test.html#Test"},{"doc":"showtime/tests/test","title":"be_error","content":"pub fn be_error(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/test.be_error\nshowtime/tests/test be_error","url":"showtime/tests/test.html#be_error"},{"doc":"showtime/tests/test","title":"be_false","content":"pub fn be_false(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/test.be_false\nshowtime/tests/test be_false","url":"showtime/tests/test.html#be_false"},{"doc":"showtime/tests/test","title":"be_ok","content":"pub fn be_ok(a: Result(a, b), meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/test.be_ok\nshowtime/tests/test be_ok","url":"showtime/tests/test.html#be_ok"},{"doc":"showtime/tests/test","title":"be_true","content":"pub fn be_true(a: Bool, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/test.be_true\nshowtime/tests/test be_true","url":"showtime/tests/test.html#be_true"},{"doc":"showtime/tests/test","title":"equal","content":"pub fn equal(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/test.equal\nshowtime/tests/test equal","url":"showtime/tests/test.html#equal"},{"doc":"showtime/tests/test","title":"fail","content":"pub fn fail(meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/test.fail\nshowtime/tests/test fail","url":"showtime/tests/test.html#fail"},{"doc":"showtime/tests/test","title":"not_equal","content":"pub fn not_equal(a: a, b: a, meta: Meta) -&gt; Nil\n\nSynonyms:\nshowtime/tests/test.not_equal\nshowtime/tests/test not_equal","url":"showtime/tests/test.html#not_equal"},{"doc":"showtime/tests/test","title":"test","content":"pub fn test(meta: Meta, test_function: fn(Meta) -&gt; Nil) -&gt; Test\n\nSynonyms:\nshowtime/tests/test.test\nshowtime/tests/test test","url":"showtime/tests/test.html#test"},{"doc":"showtime/tests/test","title":"with_meta","content":"pub fn with_meta(\n  meta: Meta,\n  test_function: fn(MetaShould(a)) -&gt; Nil,\n) -&gt; Test\n\nSynonyms:\nshowtime/tests/test.with_meta\nshowtime/tests/test with_meta","url":"showtime/tests/test.html#with_meta"},{"doc":"showtime/tests/test","title":"showtime/tests/test","content":"","url":"showtime/tests/test.html"}]);